@@ -32,9 +32,16 @@ class VWO(object):
     """ Core class of the SDK, consisting all the APIs featured in VWO Full Stack Server Side Testing """
 
     def __init__(
-        self, settings_file, user_storage, is_development_mode, goal_type_to_track, should_track_returning_user, batch_event_settings, integrations
+        self,
+        settings_file,
+        user_storage,
+        is_development_mode,
+        goal_type_to_track,
+        should_track_returning_user,
+        batch_event_settings,
+        integrations,
     ):
-        """ __init__ method to initialize the VWO object, all the argument types should be pre-checked.
+        """__init__ method to initialize the VWO object, all the argument types should be pre-checked.
         Else object initialization fails.
 
         Args:
@@ -54,10 +61,19 @@ class VWO(object):
         self.logger = VWOLogger.getInstance()
         self.config = SettingsFileManager(settings_file)
         self.settings_file = self.config.get_settings_file()
-        self.variation_decider = VariationDecider(user_storage, account_id=self.settings_file.get("accountId"), integrations=integrations)
+        self.variation_decider = VariationDecider(
+            user_storage,
+            account_id=self.settings_file.get("accountId"),
+            integrations=integrations,
+            settings_file=self.settings_file,
+        )
         if is_development_mode:
             self.logger.log(LogLevelEnum.DEBUG, LogMessageEnum.DEBUG_MESSAGES.SET_DEVELOPMENT_MODE.format(file=FILE))
-        self.event_dispatcher = EventDispatcher(is_development_mode=is_development_mode or False, batch_event_settings=batch_event_settings, sdk_key=self.settings_file.get("sdkKey"))
+        self.event_dispatcher = EventDispatcher(
+            is_development_mode=is_development_mode or False,
+            batch_event_settings=batch_event_settings,
+            sdk_key=self.settings_file.get("sdkKey"),
+        )
         self.goal_type_to_track = goal_type_to_track or GOAL_TYPES.ALL
         self.should_track_returning_user = should_track_returning_user or False
         self.logger.log(LogLevelEnum.DEBUG, LogMessageEnum.DEBUG_MESSAGES.SDK_INITIALIZED.format(file=FILE))
